@@ -3,34 +3,29 @@
 This is a small 'wrapper' to access a named vocabulary from
 portal_vocabularytool and to fetch its DisplayList
 
-RCS-ID $Id: NamedVocabulary.py 3172 2004-10-13 21:18:00Z yenzenz $
 """
-# Copyright (c) 2004-2006 by BlueDynamics Tyrol - Klein & Partner KEG, Austria
+# Copyright (c) 2004-2008 by BlueDynamics Alliance, Klein & Partner KEG, Austria
 #
 # BSD-like licence, see LICENCE.txt
 #
-__author__  = 'Jens Klein <jens.klein@bluedynamics.com>'
+__author__ = 'Jens Klein <jens@bluedynamics.com>'
 __docformat__ = 'plaintext'
 
 import Missing
+from zope.interface import implements
 from AccessControl import ClassSecurityInfo
 from Products.CMFCore.utils import getToolByName
-from Products.Archetypes.interfaces.vocabulary import IVocabulary
+from Products.Archetypes.interfaces import IVocabulary
 from Products.ATVocabularyManager.types.tree.vocabulary import TreeVocabulary
-
-try:
-    from Products.Archetypes.interfaces.vocabulary import IVocabularyTerm
-except ImportError:
-    from Products.ATVocabularyManager.backports import IVocabularyTerm
-
 from config import TOOL_NAME
 
-class NamedVocabulary:
+
+class NamedVocabulary(object):
+
+    implements(IVocabulary)
 
     vocab_name= None
 
-    __implements__ = (IVocabulary,)
-
     security = ClassSecurityInfo()
     security.setDefaultAccess('allow')
     # Add a class variable to avoid migration issues
@@ -88,9 +83,9 @@ class NamedVocabulary:
         vt = getToolByName(instance, TOOL_NAME)
         vocab = vt.getVocabularyByName(self.vocab_name)
         if vocab is None:
-            raise KeyError('Vocabulary id not found in '+\
-                             'portal_vocabularies : %s' % self.vocab_name)        
-        assert(IVocabulary.isImplementedBy(vocab))
+            raise KeyError('Vocabulary id not found in '+ \
+                'portal_vocabularies : %s' % self.vocab_name)        
+        assert(IVocabulary.providedBy(vocab))
         return vocab
 
     def getKeyPathForTerms(self, instance, terms=()):
@@ -115,7 +110,7 @@ class NamedVocabulary:
 
         # we can get a list, or just a value
         if not isinstance(terms, (tuple, list)):
-            terms=[terms,]
+            terms=[terms, ]
 
         uc = getToolByName(instance, 'uid_catalog')
 
@@ -125,7 +120,6 @@ class NamedVocabulary:
                 # term is given as termkey/uid
                 key = term
             else:
-                #XXX could ask for implements IVocabularyTerm here
                 key = term.getTermKey()
 
             result = uc(UID=key)
